@@ -41,6 +41,7 @@ class QDomElement;
 #include "engine/linkchecker.h"
 #include "parser/node.h"
 #include "parser/url.h"
+#include "parser/robotsparser.h"
 class AddLevelJob;
 
 using namespace ThreadWeaver;
@@ -89,9 +90,10 @@ public:
                   QObject *parent = 0);
     ~SearchManager();
 
-    /** Returns the the results in XML format */
+    /** Returns the results in XML format */
     QString toXML(LinkStatusHelper::Status status = LinkStatusHelper::none) const;
-
+    QString buildSiteMapXml() const;
+    
     void startSearch();
     void startSearch(KUrl const& root);
     void startSearch(KUrl const& root, SearchMode const& mode);
@@ -117,6 +119,9 @@ public:
     QString searchProtocol() const { return root_.absoluteUrl().protocol(); };
 
     void setRootUrl(KUrl const& url);
+    void setIsLoginPostRequest(bool is);
+    void setPostUrl(QString const& url);
+    void setPostData(QByteArray const& data);
     void setSearchMode(SearchMode modo);
     void setDepth(int depth);
     void setDomain(QString const& domain);
@@ -169,6 +174,7 @@ private:
     void cleanItems();
     void reset();
     SearchMode const& searchMode() const;
+    void initRobotsParser(KUrl const& url);
     bool checkRegularExpressions() const { return check_regular_expressions_; }
     bool checkParentDirs() const;
     bool checkExternalLinks() const;
@@ -209,12 +215,18 @@ private:
 private:
 
     SearchCounters search_counters_;
+
+    // authentication
+    bool is_login_post_request_;
+    QString post_url_;
+    QByteArray post_data_;
     
     // whether it is a new search or refreshing previously checked links
     bool recheck_mode_;
     int max_simultaneous_connections_;
     SearchMode search_mode_;
     KUrl root_url_;
+    RobotsParser robots_parser_;
     LinkStatus root_;
     bool has_document_root_;
     // in case of non http protocols the document root must be explicitly given
