@@ -19,18 +19,19 @@
 /* KDE INCLUDES */
 
 /* QT INCLUDES */
-#include <qwizard.h>
+#include <q3wizard.h>
+//Added by qt3to4:
+#include <QShowEvent>
 
 /* OTHER INCLUDES */
 #include <kommanderwidget.h>
-#include <kommander_export.h>
-#include <myprocess.h>
+#include "kommanderwidgets_export.h"
 
 class QShowEvent;
-class KOMMANDER_EXPORT Wizard : public QWizard, public KommanderWidget
+class KOMMANDERWIDGETS_EXPORT Wizard : public Q3Wizard, public KommanderWidget
 {
   Q_OBJECT
-
+  
   Q_PROPERTY(QString populationText READ populationText WRITE setPopulationText DESIGNABLE false)
   Q_PROPERTY(QStringList associations READ associatedText WRITE setAssociatedText DESIGNABLE false)
   Q_PROPERTY(bool KommanderWidget READ isKommanderWidget)
@@ -39,7 +40,7 @@ class KOMMANDER_EXPORT Wizard : public QWizard, public KommanderWidget
   Q_PROPERTY(QString helpActionText READ helpActionText WRITE setHelpActionText)
 
 public:
-  Wizard(QWidget *, const char *, bool = true, int = 0);
+  Wizard(QWidget *, const char *, bool=TRUE, int=0);
   ~Wizard();
 
   virtual bool isKommanderWidget() const;
@@ -48,8 +49,10 @@ public:
   virtual QString currentState() const;
   virtual QString populationText() const;
   virtual void setPopulationText(const QString&);
-
-  virtual QString handleDCOP(int function, const QStringList& args);
+  
+  virtual QString handleDBUS(int function, const QStringList& args);
+  using KommanderWidget::handleDBUS;
+    
   enum HelpAction { None, Command, Dialog };
   HelpAction helpAction() const;
   void setHelpAction(HelpAction);
@@ -59,7 +62,7 @@ public:
 public slots:
   virtual void setWidgetText(const QString &);
   virtual void exec();
-  virtual void show();
+  virtual void setVisible(bool b);
   virtual void runHelp();
   virtual void populate();
 protected slots:
@@ -70,11 +73,14 @@ signals:
   void widgetOpened();
   void widgetTextChanged(const QString &);
   void finished();
+  void contextMenuRequested(int xpos, int ypos);
 protected:
+  void showEvent( QShowEvent *e );
+  void contextMenuEvent( QContextMenuEvent * e );
+
   HelpAction m_helpAction;
   QString m_helpActionText;
-  void showEvent( QShowEvent *e );
-private:
+  bool m_firstShow;
 };
 
 #endif
